@@ -1,3 +1,4 @@
+from typing import Optional, Union, Coroutine
 import inspect
 
 import ducts_client
@@ -7,7 +8,15 @@ class DuctEventListener(ducts_client.event_listeners.DuctEventListener):
         self._duct = duct
         self._handlers = {}
 
-    def on(self, names, success = None, error = None, complete = None):
+    def on(self, names: Union[str, list[str]], success: Optional[Coroutine] = None, error: Optional[Coroutine] = None, complete: Optional[Coroutine] = None):
+        """Sets an event listener to specified controller method(s) in ``names`` argument.
+
+        Args:
+            names (:obj:`str` or :obj:`list`): A name/names of controller methods to set event listeners for.
+            success (:obj:`coroutine`, optional): A function to handle successful responses with. Specified coroutine needs to have one argument which has a successful response object.
+            error (:obj:`coroutine`, optional): A function to handle error responses with. Specified coroutine needs to have one  argument which has an error response object.
+            complete (:obj:`coroutine`, optional): A function to handle responses with. Specified coroutine cannot have any argument.
+        """
         if not (inspect.iscoroutinefunction(success) or success is None) \
             or not (inspect.iscoroutinefunction(error) or error is None) \
             or not (inspect.iscoroutinefunction(complete) or complete is None):
@@ -95,6 +104,18 @@ class ResourceEventListener(DuctEventListener):
                     duct.EVENT['RESPONSE_LIST_FOR_WORKER'],
                 'list_responses_for_work_session':
                     duct.EVENT['RESPONSE_LIST_FOR_WORK_SESSION'],
+                'watch_responses_for_project':
+                    duct.EVENT['RESPONSE_WATCH_FOR_PROJECT'],
+                'watch_responses_for_template':
+                    duct.EVENT['RESPONSE_WATCH_FOR_TEMPLATE'],
+                'watch_responses_for_nanotask':
+                    duct.EVENT['RESPONSE_WATCH_FOR_NANOTASK'],
+                'watch_responses_for_worker':
+                    duct.EVENT['RESPONSE_WATCH_FOR_WORKER'],
+                'watch_responses_for_automation_parameter_set':
+                    duct.EVENT['RESPONSE_WATCH_FOR_AUTOMATION_PARAMETER_SET'],
+                'watch_responses_for_platform_parameter_set':
+                    duct.EVENT['RESPONSE_WATCH_FOR_PLATFORM_PARAMETER_SET'],
                 'list_projects_with_responses':
                     duct.EVENT['RESPONSE_LIST_PROJECTS'],
                 'list_templates_with_responses':
